SystemOrganization addCategory: #CloudFoundry!

Object subclass: #CloudFoundry
	instanceVariableNames: 'base'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CloudFoundry'!

!CloudFoundry class methodsFor: 'constants' stamp: 'tfel 2/21/2012 14:24'!
availableFrameworks

	^ #('squeak' 'pharo')! !

!CloudFoundry class methodsFor: 'deployment' stamp: 'tfel 2/21/2012 17:21'!
generateDroplet
	| base |
	(FileDirectory default directoryNamed: self pushFolder) assureExistence.
	base := UIManager default
				chooseFrom: self availableFrameworks
				values: self availableFrameworks
				title: 'Choose your base image'.
	self new
		base: base;
		generateDroplet.! !

!CloudFoundry class methodsFor: 'constants' stamp: 'tfel 2/21/2012 14:25'!
pushFolder

	^ 'vmc'! !

!CloudFoundry methodsFor: 'deployment' stamp: 'tfel 2/22/2012 19:08'!
addVNCTo: file

	file
		nextPutAll: '(Installer ss project: ''RFB'') install: ''RFB''';
		nextPutAll: 'RFBServer start: ';
		nextPutAll: (UIManager default
						request: 'What display should the VNC server run on (add 5900 to get the port): '
						initialAnswer: '5');
		nextPut: $.;
		crlf.

! !

!CloudFoundry methodsFor: 'accessing' stamp: 'tfel 2/21/2012 17:21'!
base
	"Answer the value of base"

	^ base! !

!CloudFoundry methodsFor: 'accessing' stamp: 'tfel 2/21/2012 17:21'!
base: anObject
	"Set the value of base"

	base := anObject! !

!CloudFoundry methodsFor: 'file operations' stamp: 'tfel 2/21/2012 17:38'!
copyPackage: config toStagingAreaWith: file
	| fileName |
	fileName := (MCPackage named: config) workingCopy currentVersionInfo name, '.mcz'.
	MCCacheRepository default directory
		copyFileNamed: fileName
		toFileNamed: file directory pathName, FileDirectory slash, fileName.
! !

!CloudFoundry methodsFor: 'deployment' stamp: 'tfel 2/21/2012 17:31'!
generateDroplet

	self generatePushFile: [:file |
		[self confirm: 'Load a(nother) metacello config?'] whileTrue: [
				self loadMetacelloConfig: file].
			[self confirm: 'Load an(other) mcz?'] whileTrue: [
				self loadMcz: file]].! !

!CloudFoundry methodsFor: 'deployment' stamp: 'tfel 2/22/2012 19:04'!
generateDropletWithVNC

	self generatePushFile: [:file |
		[self confirm: 'Load a(nother) metacello config?'] whileTrue: [
				self loadMetacelloConfig: file].
			[self confirm: 'Load an(other) mcz?'] whileTrue: [
				self loadMcz: file].
			self addVNCTo: file].! !

!CloudFoundry methodsFor: 'deployment' stamp: 'tfel 2/21/2012 17:27'!
generatePushFile: aBlock

	FileStream
		forceNewFileNamed: self class pushFolder, FileDirectory slash, self base, '.st'
		do: aBlock.! !

!CloudFoundry methodsFor: 'file operations' stamp: 'tfel 2/21/2012 17:22'!
goferPackage: config from: file

	file
		nextPutAll: 'Gofer it directory: ''.''; package: ';
		nextPutAll: config printString;
		nextPutAll: '; load.';
		crlf.! !

!CloudFoundry methodsFor: 'file operations' stamp: 'tfel 2/21/2012 17:22'!
installPackage: config from: file

	file
		nextPutAll: 'Installer mc directory: ''.''; package: ';
		nextPutAll: config printString;
		nextPutAll: '; install.';
		crlf.! !

!CloudFoundry methodsFor: 'deployment' stamp: 'tfel 2/21/2012 17:40'!
loadMcz: aFile
	| package packages |
	packages := PackageOrganizer default packageNames.
	package := UIManager default chooseFrom: packages values: packages.
	self copyPackage: package toStagingAreaWith: aFile.
	self loadPackage: package from: aFile.
! !

!CloudFoundry methodsFor: 'deployment' stamp: 'tfel 2/21/2012 17:31'!
loadMetacelloConfig: aFile
	| classes class version group |
	classes := (Smalltalk globals
					select: [:cls | cls asString beginsWith: 'ConfigurationOf']
					thenCollect: [:cls | cls asString]) asOrderedCollection.
	class := UIManager default
		chooseFrom: classes
		values: classes
		title: 'Which Metacello configuration should be loaded?'.
	version := UIManager default
					request: 'What version should we load?'
					initialAnswer: (Smalltalk at: class asSymbol) project
										lastVersion versionNumber asString.
	group := UIManager default
					request: 'What group should we load?'
					initialAnswer: 'default'.
	self copyPackage: class toStagingAreaWith: aFile.
	self loadPackage: class from: aFile.
	aFile
		nextPutAll: '((Smalltalk at: #';
		nextPutAll: class printString;
		nextPutAll: ') project version: ';
		nextPutAll: version printString;
		nextPutAll: ') load: #(';
		nextPutAll: group printString;
		nextPutAll: ').';
		crlf.
! !

!CloudFoundry methodsFor: 'file operations' stamp: 'tfel 2/21/2012 17:28'!
loadPackage: config from: file

	((Dictionary newFrom: {
		'pharo' -> [self goferPackage: config from: file].
		'squeak' -> [self installPackage: config from: file] }) at: self base) value! !

Object subclass: #CloudFoundryService
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'CloudFoundry'!

!CloudFoundryService class methodsFor: 'class initialization' stamp: 'tfel 2/21/2012 16:57'!
initialize
	"self initialize"
	super initialize.
	Smalltalk addToStartUpList: self.
	Smalltalk addToShutDownList: self.! !

!CloudFoundryService class methodsFor: 'testing' stamp: 'tfel 2/21/2012 17:42'!
isAbstract

	^ self name = #CloudFoundryService! !

!CloudFoundryService class methodsFor: 'system startup' stamp: 'tfel 2/21/2012 17:02'!
runInCloudFoundry: aPortNumber

	self subclassResponsibility.! !

!CloudFoundryService class methodsFor: 'system startup' stamp: 'tfel 2/21/2012 17:02'!
shutDown

	self isAbstract ifTrue: [^ self].
	self stopInCloudFoundry.
! !

!CloudFoundryService class methodsFor: 'system startup' stamp: 'tfel 2/21/2012 17:02'!
startUp
	"Start this app if running on cloud foundry"
	self isAbstract ifTrue: [^ self].
	(SmalltalkImage current getSystemAttribute: 3)
		ifNil: [self]
		ifNotNilDo: [:number | self runInCloudFoundry: number asInteger].! !

!CloudFoundryService class methodsFor: 'system startup' stamp: 'tfel 2/21/2012 17:02'!
stopInCloudFoundry

	self subclassResponsibility.! !

!CloudFoundryService class methodsFor: 'testing' stamp: 'tfel 2/21/2012 17:03'!
vcapAppPort

	^ (SmalltalkImage current getSystemAttribute: 3)
		ifNotNilDo: [:string | string asNumber]! !
CloudFoundryService initialize!
